Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CopyTool ¶
type CopyTool interface {
// Name returns the name of the copy tool.
Name() string
// Command builds and returns the exec.Cmd for the copy operation. If opts is set, it is used for this invocation instead of the tool's Options set during initialization, without modifying the stored Options.
Command(ctx context.Context, paths []string, opts *Options) (*exec.Cmd, error)
// IsAvailableOnGuest checks if the tool is available on the specified guest instance.
IsAvailableOnGuest(ctx context.Context, paths []string) bool
}
CopyTool is the interface for copy tool implementations.
type Options ¶
type Options struct {
Recursive bool
Verbose bool
AdditionalArgs []string // Make sure that the additional args are valid for a specific tool and escaped before passing them here.
}
Options contains common options for copy operations. This might not be a complete list; more options can be added as needed.
Click to show internal directories.
Click to hide internal directories.